@@ -94,7 +94,8 @@ public:
     {
         bool allMenuBarsNative = true;
         bool hasAnyMenuBar = false;
-        foreach(QWidget *w, qApp->topLevelWidgets()) {
+        const auto lstWidget = qApp->topLevelWidgets();
+        for (QWidget *w : lstWidget) {
             QMainWindow *mw = qobject_cast<QMainWindow*>(w);
             if (mw) {
                 mw->installEventFilter(this); // this is just in case a new main window appeared
@@ -210,7 +211,8 @@ QAction* _k_createInternal(StandardAction id, QObject *parent)
             pAction->setChecked(true);
 
             ShowMenubarActionFilter *mf = new ShowMenubarActionFilter(pAction);
-            foreach(QWidget *w, qApp->topLevelWidgets()) {
+            const auto lstWidget = qApp->topLevelWidgets();
+            for (QWidget *w : lstWidget) {
                 if (qobject_cast<QMainWindow*>(w)) {
                     w->installEventFilter(mf);
                 }
@@ -232,7 +234,7 @@ QAction* _k_createInternal(StandardAction id, QObject *parent)
             pAction = new KToggleFullScreenAction(parent);
             pAction->setCheckable(true);
             break;
-#ifndef KDE_NO_DEPRECATED
+#if !defined(KDE_NO_DEPRECATED) && defined(QT_DBUS_LIB)
         case PasteText:
             pAction = new KPasteTextAction(parent);
             break;
@@ -294,7 +296,7 @@ QAction* _k_createInternal(StandardAction id, QObject *parent)
     }
 
     if (pAction && parent && parent->inherits("KActionCollection")) {
-        QMetaObject::invokeMethod(parent, "addAction", Q_ARG(QString, pAction->objectName()), Q_ARG(QAction *, pAction));
+        QMetaObject::invokeMethod(parent, "addAction", Q_ARG(QString, pAction->objectName()), Q_ARG(QAction*, pAction));
     }
 
     return pAction;
@@ -585,7 +587,7 @@ static QAction *buildAutomaticAction(QObject *parent, StandardAction id, const c
     }
 
     if (parent && parent->inherits("KActionCollection")) {
-        QMetaObject::invokeMethod(parent, "addAction", Q_ARG(QString, action->objectName()), Q_ARG(QAction *, action));
+        QMetaObject::invokeMethod(parent, "addAction", Q_ARG(QString, action->objectName()), Q_ARG(QAction*, action));
     }
 
     return action;
